@@ -5,14 +5,14 @@ Place::Place(QObject *parent) :
 {
 }
 
-Place::Place(const Place &other) : QObject(other.parent())
+Place::Place(const Place &other,QObject *parent) : QObject(parent)
 {
     this->_id = QString(other._id);
     this->_name = QString(other._name);
     this->_address = QString(other._address);
 }
 
-Place::Place(const Place *other) : QObject(other->parent())
+Place::Place(const Place *other,QObject *parent) : QObject(parent)
 {
     this->_id = QString(other->_id);
     this->_name = QString(other->_name);
