@@ -12,8 +12,8 @@ class Place : public QObject
 
 public:
     explicit Place(QObject *parent = 0);
-    Place(const Place &other);
-    Place(const Place *other);
+    Place(const Place &other, QObject *parent = 0);
+    Place(const Place *other, QObject *parent = 0);
 
 
     QString getId() {return _id;}
