@@ -269,7 +269,7 @@ void FbActions::do_configuration()
 {
     ConfigDialog config_dialog;
     if (settings_manager.is_prefer_g_rated_tag_line())
-        config_dialog.set_tagline_G(false);
+        config_dialog.set_tagline_G(true);
     else
         config_dialog.set_tagline_non_G(true);
 
